@@ -12,6 +12,7 @@
 """Media archive module"""
 
 import logging
+from typing import Any
 
 import superdesk
 from superdesk.celery_app import celery
@@ -38,15 +39,15 @@ from apps.item_lock.models.item import ItemModel
 from apps.common.models.io.eve_proxy import EveProxy
 from .archive_rewrite import ArchiveRewriteResource, ArchiveRewriteService
 from .news import NewsResource, NewsService
-from flask_babel import _
+from flask_babel import _, lazy_gettext
 
 logger = logging.getLogger(__name__)
 
 
-def init_app(app):
+def init_app(app) -> None:
 
     endpoint_name = "ingest"
-    service = AppIngestService(endpoint_name, backend=superdesk.get_backend())
+    service: Any = AppIngestService(endpoint_name, backend=superdesk.get_backend())
     IngestResource(endpoint_name, app=app, service=service)
 
     endpoint_name = "archive_versions"
@@ -106,24 +107,38 @@ def init_app(app):
     register_model(ItemAutosaveModel(EveProxy(superdesk.get_backend())))
 
     superdesk.privilege(
-        name="monitoring_view", label=_("Monitoring view"), description=_("Access to Monitoring view in left toolbar")
+        name="monitoring_view",
+        label=lazy_gettext("Monitoring view"),
+        description=lazy_gettext("Access to Monitoring view in left toolbar"),
     )
-    superdesk.privilege(name="archive", label=_("Create content"), description=_("Create and save content"))
-    superdesk.privilege(name="ingest", label=_("Ingest"), description=_("Access to ingest sources management"))
-    superdesk.privilege(name="spike", label=_("Spike"), description=_("Spike/delete items"))
-    superdesk.privilege(name="spike_read", label=_("Spike view"), description=_("View spiked content"))
-    superdesk.privilege(name="unspike", label=_("Unspike"), description=_("Unspike/undelete content"))
-    superdesk.privilege(name="metadata_uniquename", label=_("Edit Unique Name"), description=_("Edit unique name"))
-    superdesk.privilege(name="hold", label=_("Hold"), description=_("Hold content"))
-    superdesk.privilege(name="restore", label=_("Restore"), description=_("Restore content"))
-    superdesk.privilege(name="rewrite", label=_("Update"), description=_("Create an update"))
     superdesk.privilege(
-        name="unlock", label=_("Unlock content"), description=_("Unlock locked content by another user")
+        name="archive", label=lazy_gettext("Create content"), description=lazy_gettext("Create and save content")
+    )
+    superdesk.privilege(
+        name="ingest", label=lazy_gettext("Ingest"), description=lazy_gettext("Access to ingest sources management")
+    )
+    superdesk.privilege(name="spike", label=lazy_gettext("Spike"), description=lazy_gettext("Spike/delete items"))
+    superdesk.privilege(
+        name="spike_read", label=lazy_gettext("Spike view"), description=lazy_gettext("View spiked content")
+    )
+    superdesk.privilege(
+        name="unspike", label=lazy_gettext("Unspike"), description=lazy_gettext("Unspike/undelete content")
+    )
+    superdesk.privilege(
+        name="metadata_uniquename", label=lazy_gettext("Edit Unique Name"), description=lazy_gettext("Edit unique name")
+    )
+    superdesk.privilege(name="hold", label=lazy_gettext("Hold"), description=lazy_gettext("Hold content"))
+    superdesk.privilege(name="restore", label=lazy_gettext("Restore"), description=lazy_gettext("Restore content"))
+    superdesk.privilege(name="rewrite", label=lazy_gettext("Update"), description=lazy_gettext("Create an update"))
+    superdesk.privilege(
+        name="unlock",
+        label=lazy_gettext("Unlock content"),
+        description=lazy_gettext("Unlock locked content by another user"),
     )
     superdesk.privilege(
         name="mark_for_user",
-        label=_("Mark items for users"),
-        description=_("User can mark or unmark items for other users"),
+        label=lazy_gettext("Mark items for users"),
+        description=lazy_gettext("User can mark or unmark items for other users"),
     )
 
     superdesk.intrinsic_privilege(ArchiveUnlockResource.endpoint_name, method=["POST"])
