@@ -90,6 +90,7 @@ from apps.content import push_content_notification, push_expired_notification, p
 from apps.common.models.utils import get_model
 from apps.item_lock.models.item import ItemModel
 from apps.packages import PackageService
+from superdesk.privilege import GLOBAL_SEARCH_PRIVILEGE
 from .archive_media import ArchiveMediaService
 from .usage import track_usage, update_refs
 from superdesk.utc import utcnow
@@ -105,7 +106,7 @@ def format_subj_qcode(subj):
 
 
 def private_content_filter():
-    """Filter out out users private content if this is a user request.
+    """Filter out other users private content if this is a user request.
 
     As private we treat items where user is creator, last version creator,
     or has the item assigned to him atm.
@@ -116,7 +117,7 @@ def private_content_filter():
     if user:
         private_filter = {
             "should": [
-                {"exists": {"field": "task.desk"}},
+                # assigned to me or created by me
                 {"term": {"task.user": str(user["_id"])}},
                 {"term": {"version_creator": str(user["_id"])}},
                 {"term": {"original_creator": str(user["_id"])}},
@@ -134,14 +135,23 @@ def private_content_filter():
 
         # user can see all public content
         # as long as it's not drafts
-        private_filter["should"].append(
-            {
-                "bool": {
-                    "must": {"exists": {"field": "task.desk"}},
-                    "must_not": {"term": {"state": "draft"}},
+        if current_user_has_privilege(GLOBAL_SEARCH_PRIVILEGE):
+            private_filter["should"].append(
+                {
+                    "bool": {
+                        "must": {"exists": {"field": "task.desk"}},
+                        "must_not": {"term": {"state": "draft"}},
+                    }
                 }
-            }
-        )
+            )
+
+        # if user has no global search access, only show him content on his desks
+        # and not on any desk
+        else:
+            desks = get_resource_service("user_desks").get_by_user(user["_id"]) or []
+            private_filter["should"].append(
+                {"terms": {"task.desk": [str(d["_id"]) for d in desks]}},
+            )
 
         return {
             "bool": {
