@@ -13,7 +13,7 @@ import logging
 import superdesk
 
 from datetime import timedelta
-from flask import request, current_app as app
+from flask import request, current_app as app, json
 from eve.auth import TokenAuth
 from superdesk.resource import Resource
 from superdesk.errors import SuperdeskApiError
@@ -77,7 +77,8 @@ class SuperdeskTokenAuth(TokenAuth):
     def check_permissions(self, resource, method, user):
         """Checks user permissions.
 
-        1. If there's no user associated with the request or HTTP Method is GET then return True.
+        1. If there's no user associated with the request or HTTP Method is GET or the Resource is a Flask Blueprint
+        then return True.
         2. Get User's Privileges
         3. Intrinsic Privileges:
             Check if resource has intrinsic privileges.
@@ -96,10 +97,18 @@ class SuperdeskTokenAuth(TokenAuth):
         if not user:
             return True
 
+        if resource == "_blueprint":
+            return True
+
         # Step 2: Get User's Privileges
         get_resource_service("users").set_privileges(user, flask.g.role)
 
-        if method == "GET":
+        try:
+            resource_privileges = get_resource_privileges(resource).get(method, None)
+        except KeyError:
+            resource_privileges = None
+
+        if method == "GET" and not resource_privileges:
             return True
 
         # Step 3: Intrinsic Privileges
@@ -118,7 +127,6 @@ class SuperdeskTokenAuth(TokenAuth):
 
         # Step 4: User's privileges
         privileges = user.get("active_privileges", {})
-        resource_privileges = get_resource_privileges(resource).get(method, None)
 
         if not resource_privileges and get_no_resource_privileges(resource):
             return True
