@@ -8,6 +8,8 @@
 # AUTHORS and LICENSE files distributed with this source code, or
 # at https://www.sourcefabric.org/superdesk/license
 
+from typing import Any
+from flask_babel import lazy_gettext
 import superdesk
 from superdesk import get_backend
 
@@ -24,9 +26,9 @@ from apps.content_filters.filter_condition.filter_condition_parameters import (
 from apps.content_filters.content_filter.content_filter_test import ContentFilterTestResource, ContentFilterTestService
 
 
-def init_app(app):
+def init_app(app) -> None:
     endpoint_name = "filter_conditions"
-    service = FilterConditionService(endpoint_name, backend=get_backend())
+    service: Any = FilterConditionService(endpoint_name, backend=get_backend())
     FilterConditionResource(endpoint_name, app=app, service=service)
 
     endpoint_name = "filter_condition_parameters"
@@ -41,4 +43,8 @@ def init_app(app):
     service = ContentFilterTestService(endpoint_name, backend=superdesk.get_backend())
     ContentFilterTestResource(endpoint_name, app=app, service=service)
 
-    superdesk.privilege(name="content_filters", label="Content Filters", description="User can manage content filters")
+    superdesk.privilege(
+        name="content_filters",
+        label=lazy_gettext("Content Filters"),
+        description=lazy_gettext("User can manage content filters"),
+    )
