@@ -28,7 +28,7 @@ from superdesk.activity import add_activity, ACTIVITY_UPDATE
 from superdesk.metadata.item import FAMILY_ID, ITEM_STATE, CONTENT_STATE
 from eve.utils import ParsedRequest
 from superdesk.utils import ListCursor
-from flask_babel import _
+from flask_babel import _, lazy_gettext
 
 
 logger = logging.getLogger(__name__)
@@ -85,9 +85,9 @@ desks_schema = {
 }
 
 
-def init_app(app):
+def init_app(app) -> None:
     endpoint_name = "desks"
-    service = DesksService(endpoint_name, backend=superdesk.get_backend())
+    service: Any = DesksService(endpoint_name, backend=superdesk.get_backend())
     DesksResource(endpoint_name, app=app, service=service)
     endpoint_name = "user_desks"
     service = UserDesksService(endpoint_name, backend=superdesk.get_backend())
@@ -100,8 +100,12 @@ def init_app(app):
     OverviewResource(endpoint_name, app=app, service=service)
 
 
-superdesk.privilege(name="desks", label="Desk Management", description="User can manage desks.")
-superdesk.privilege(name="masterdesk", label="Master Desk", description="User can access master desk.")
+superdesk.privilege(
+    name="desks", label=lazy_gettext("Desk Management"), description=lazy_gettext("User can manage desks.")
+)
+superdesk.privilege(
+    name="masterdesk", label=lazy_gettext("Master Desk"), description=lazy_gettext("User can access master desk.")
+)
 
 
 class DesksResource(Resource):
@@ -369,6 +373,9 @@ class UserDesksService(BaseService):
         # desk = list(self.get(req=None, lookup={'members.user':ObjectId(user_id), '_id': ObjectId(desk_id)}))
         return len(list(self.get(req=None, lookup={"members.user": ObjectId(user_id), "_id": ObjectId(desk_id)}))) > 0
 
+    def get_by_user(self, user_id):
+        return list(self.get(req=None, lookup={"user_id": user_id}))
+
 
 class SluglineDesksResource(Resource):
 
