@@ -8,6 +8,8 @@
 # AUTHORS and LICENSE files distributed with this source code, or
 # at https://www.sourcefabric.org/superdesk/license
 
+from typing import Any
+from flask_babel import lazy_gettext
 import superdesk
 from apps.auth import AuthResource
 from .ldap import ADAuthService, ADAuth, ImportUserProfileResource, ImportUserProfileService  # noqa
@@ -15,12 +17,14 @@ from .commands import ImportUserProfileFromADCommand  # noqa
 from .users_service import ADUsersService, UsersResource, is_admin  # NOQA
 
 
-def init_app(app):
+def init_app(app) -> None:
     endpoint_name = "users"
-    service = ADUsersService(endpoint_name, backend=superdesk.get_backend())
+    service: Any = ADUsersService(endpoint_name, backend=superdesk.get_backend())
     UsersResource(endpoint_name, app=app, service=service)
 
-    superdesk.privilege(name="users", label="User Management", description="User can manage users.")
+    superdesk.privilege(
+        name="users", label=lazy_gettext("User Management"), description=lazy_gettext("User can manage users.")
+    )
 
     # Registering with intrinsic privileges because: A user should be allowed to update their own profile.
     superdesk.intrinsic_privilege(resource_name="users", method=["PATCH"])
