@@ -16,7 +16,7 @@ from .app_initialize import AppInitializeWithDataCommand  # NOQA
 from .app_scaffold_data import AppScaffoldDataCommand  # NOQA
 
 
-def init_app(app):
+def init_app(app) -> None:
     if superdesk.app.config.get("SUPERDESK_TESTING", False):
         endpoint_name = "prepopulate"
         service = PrepopulateService(endpoint_name, backend=superdesk.get_backend())
