@@ -626,6 +626,8 @@ class BasePublishService(BaseService):
             if type(item) == dict and item.get(config.ID_FIELD):
                 doc = item
                 orig = super().find_one(req=None, _id=item[config.ID_FIELD])
+                if not app.settings.get("COPY_METADATA_FROM_PARENT") and orig:
+                    doc = orig
                 try:
                     doc.update({"lock_user": orig["lock_user"]})
                 except (TypeError, KeyError):
@@ -773,7 +775,6 @@ class BasePublishService(BaseService):
         for associations_key, associated_item in associations.items():
             if associated_item is None:
                 continue
-
             if type(associated_item) == dict and associated_item.get(config.ID_FIELD):
                 if not config.PUBLISH_ASSOCIATED_ITEMS or not publish_service:
                     if original.get(ASSOCIATIONS, {}).get(associations_key):
@@ -865,6 +866,8 @@ class BasePublishService(BaseService):
                         remove_unwanted(association_updates)
                         publish_service.patch(id=association_updates.pop(config.ID_FIELD), updates=association_updates)
 
+            # When there is an associated item which is published, Inserts the latest version of that associated item into archive_versions.
+            insert_into_versions(doc=associated_item)
         self._refresh_associated_items(original)
 
     def _mark_media_item_as_used(self, updates, original):
