@@ -13,7 +13,7 @@ from .service import ItemsService
 from .resource import ItemsResource
 
 
-def init_app(app):
+def init_app(app) -> None:
     """Initialize the `items` API endpoint.
 
     :param app: the API application object
