@@ -25,6 +25,6 @@ def upload_url(media_id, view=prod_get_upload_as_data_uri):
     return "{}/{}".format(app.config.get("MEDIA_PREFIX").rstrip("/"), media_id)
 
 
-def init_app(app):
+def init_app(app) -> None:
     superdesk.blueprint(bp, app)
     app.upload_url = upload_url
