@@ -15,19 +15,15 @@ from apps.contacts.resource import ContactsResource as _ContactsResource
 
 
 class ContactsResource(Resource):
-    url = 'contacts'
+    url = "contacts"
     item_url = item_url
-    item_methods = ['GET']
-    resource_methods = ['GET']
+    item_methods = ["GET"]
+    resource_methods = ["GET"]
     schema = _ContactsResource.schema.copy()
     datasource = {
-        'source': 'contacts',
-        'search_backend': 'elastic',
-        'default_sort': [('last_name.keyword', 1)],
-        'projection': {
-            'fields_meta': 0
-        },
-    }
-    privileges = {
-        'GET': Scope.CONTACTS_READ.name
+        "source": "contacts",
+        "search_backend": "elastic",
+        "default_sort": [("last_name.keyword", 1)],
+        "projection": {"fields_meta": 0},
     }
+    privileges = {"GET": Scope.CONTACTS_READ.name}
