@@ -12,10 +12,4 @@ from ..service import ProdApiService
 
 
 class ContactsService(ProdApiService):
-    excluded_fields = {
-        '_etag',
-        '_type',
-        '_updated',
-        '_created',
-        '_links'
-    }
+    excluded_fields = {"_etag", "_type", "_updated", "_created", "_links"}
