@@ -12,11 +12,14 @@
 
 import blinker
 import logging as logging_lib
-from flask import abort, json, Blueprint, current_app as app  # noqa
-from flask_script import Command as BaseCommand, Option  # noqa
-from werkzeug.exceptions import HTTPException
+
+from typing import Any, Dict, NamedTuple, Optional
+from flask import abort, json, Blueprint, current_app as app
+from flask_babel.speaklater import LazyString
+from flask_script import Command as BaseCommand, Option
 from eve.utils import config  # noqa
 from eve.methods.common import document_link  # noqa
+from werkzeug.exceptions import HTTPException
 
 from .eve_backend import EveBackend
 from .datalayer import SuperdeskDataLayer  # noqa
@@ -25,23 +28,31 @@ from .resource import Resource  # noqa
 from .privilege import privilege, intrinsic_privilege, get_intrinsic_privileges  # noqa
 from .workflow import *  # noqa
 from .signals import *  # noqa
+from apps.common.models.base_model import BaseModel
+from apps.common.components.base_component import BaseComponent
 
-__version__ = "2.1.6"
+__version__ = "2.2.0"
 
 API_NAME = "Superdesk API"
 SCHEMA_VERSION = 1
 DOMAIN = {}
 COMMANDS = {}
 JINJA_FILTERS = dict()
-app_components = dict()
-app_models = dict()
-resources = dict()
+app_components: Dict[str, BaseComponent] = dict()
+app_models: Dict[str, BaseModel] = dict()
+resources: Dict[str, Resource] = dict()
 _eve_backend = EveBackend()
-default_user_preferences = dict()
-default_session_preferences = dict()
+default_user_preferences: Dict[str, "UserPreference"] = dict()
+default_session_preferences: Dict[str, Any] = dict()
 logger = logging_lib.getLogger(__name__)
 
 
+class UserPreference(NamedTuple):
+    value: Any
+    label: Optional[LazyString] = None
+    category: Optional[LazyString] = None
+
+
 class Command(BaseCommand):
     """Superdesk Command.
 
@@ -117,8 +128,18 @@ def get_no_resource_privileges(resource_name):
     return attr
 
 
-def register_default_user_preference(preference_name, preference):
-    default_user_preferences[preference_name] = preference
+def register_default_user_preference(
+    preference_name: str,
+    preference: Dict[str, Any],
+    label: Optional[LazyString] = None,
+    category: Optional[LazyString] = None,
+):
+    # this part is temporary so I can update core before updating planning
+    if label is None:
+        label = preference.pop("label", None)
+    if category is None:
+        category = preference.pop("category", None)
+    default_user_preferences[preference_name] = UserPreference(preference, label, category)
 
 
 def register_default_session_preference(preference_name, preference):
