@@ -90,6 +90,12 @@ ELASTIC_DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S"
 #: .. versionadded:: 1.34
 #:
 ELASTIC_DEFAULT_SIZE = 10
+
+#: allow wildcards in query string
+#:
+#: https://discuss.elastic.co/t/configuring-the-standard-tokenizer/8691/5
+ELASTIC_QUERY_STRING_ANALYZE_WILDCARD = False
+
 PAGINATION_LIMIT = 200
 
 MERGE_NESTED_DOCUMENTS = False
@@ -104,6 +110,9 @@ LOG_CONFIG_FILE = env("LOG_CONFIG_FILE", "logging_config.yml")
 LOG_SERVER_ADDRESS = env("LOG_SERVER_ADDRESS", "localhost")
 LOG_SERVER_PORT = int(env("LOG_SERVER_PORT", 5555))
 
+SAMS_HOST = env("SAMS_HOST", "localhost")
+SAMS_PORT = env("SAMS_PORT", 5700)
+
 #: application name - used in email footers, ``APP_NAME`` env
 APPLICATION_NAME = env("APP_NAME", "Superdesk")
 #: public client url - used to create links within emails etc, ``SUPERDESK_CLIENT_URL`` env
@@ -162,9 +171,6 @@ CONTENTAPI_ELASTICSEARCH_URL = env("CONTENTAPI_ELASTICSEARCH_URL", ELASTICSEARCH
 ELASTICSEARCH_INDEX = env("ELASTICSEARCH_INDEX", "superdesk")
 CONTENTAPI_ELASTICSEARCH_INDEX = env("CONTENTAPI_ELASTICSEARCH_INDEX", CONTENTAPI_MONGO_DBNAME)
 
-if env("ELASTIC_PORT"):
-    ELASTICSEARCH_URL = env("ELASTIC_PORT").replace("tcp:", "http:")
-
 ELASTICSEARCH_BACKUPS_PATH = env("ELASTICSEARCH_BACKUPS_PATH", "")
 
 #: elastic settings - superdesk custom filter
@@ -190,10 +196,11 @@ ELASTICSEARCH_SETTINGS = {
                     "char_filter": ["html_strip_filter"],
                 },
             },
-        }
-    }
+        },
+    },
 }
 
+
 CONTENTAPI_ELASTICSEARCH_SETTINGS = {
     "settings": {
         "analysis": {
@@ -215,8 +222,6 @@ ELASTICSEARCH_TRACK_TOTAL_HITS = True
 
 #: redis url
 REDIS_URL = env("REDIS_URL", "redis://localhost:6379")
-if env("REDIS_PORT"):
-    REDIS_URL = env("REDIS_PORT").replace("tcp:", "redis:")
 
 #: cache url - superdesk will try to figure out if it's redis or memcached
 CACHE_URL = env("SUPERDESK_CACHE_URL", REDIS_URL)
@@ -352,7 +357,6 @@ CORE_APPS = [
     "superdesk.attachments",
     "superdesk.auth_server",
     "apps.links",
-    "apps.languages",
     "superdesk.locales",
 ]
 
@@ -470,6 +474,7 @@ CORE_APPS.extend(
         "apps.concept_items",
         "superdesk.places",
         "apps.desk_routing",
+        "apps.system_message",
     ]
 )
 
@@ -479,6 +484,9 @@ EXTENDED_MEDIA_INFO = ["content_type", "name", "length", "_id"]
 RETURN_MEDIA_AS_BASE64_STRING = False
 VERSION = "_current_version"
 
+#: media storage provider
+MEDIA_STORAGE_PROVIDER = env("MEDIA_STORAGE_PROVIDER")
+
 #: uses for generation of media url ``(<media_prefix>/<media_id>)``::
 MEDIA_PREFIX = env("MEDIA_PREFIX", "%s/upload-raw" % SERVER_URL.rstrip("/"))
 MEDIA_PREFIXES_TO_FIX = None
