@@ -9,13 +9,16 @@
 # at https://www.sourcefabric.org/superdesk/license
 
 
+from flask_babel import lazy_gettext
 from .roles import RolesResource, RolesService
 import superdesk
 
 
-def init_app(app):
+def init_app(app) -> None:
     endpoint_name = "roles"
     service = RolesService(endpoint_name, backend=superdesk.get_backend())
     RolesResource(endpoint_name, app=app, service=service)
 
-    superdesk.privilege(name="roles", label="Roles Management", description="User can manage roles.")
+    superdesk.privilege(
+        name="roles", label=lazy_gettext("Roles Management"), description=lazy_gettext("User can manage roles.")
+    )
