@@ -24,6 +24,9 @@ from flask import json, Config
 from apps.ldap import ADAuth
 from superdesk import get_resource_service
 from superdesk.factory import get_app
+from superdesk.factory.app import get_media_storage_class
+from superdesk.storage.amazon_media_storage import AmazonMediaStorage
+from superdesk.storage.proxy import ProxyMediaStorage
 
 logger = logging.getLogger(__name__)
 test_user = {
@@ -36,10 +39,8 @@ test_user = {
     "email": "behave_test@sourcefabric.org",
     "preferences": {
         "email:notification": {
-            "label": "Send notifications via email",
             "type": "bool",
             "default": True,
-            "category": "notifications",
             "enabled": True,
         }
     },
@@ -176,6 +177,16 @@ def setup_config(config):
 
     update_config(app_config)
 
+    app_config.setdefault("INSTALLED_APPS", [])
+
+    # Extend the INSTALLED APPS with the list provided
+    if config:
+        config.setdefault("INSTALLED_APPS", [])
+        app_config["INSTALLED_APPS"].extend(config.pop("INSTALLED_APPS", []))
+
+    # Make sure there are no duplicate entries in INSTALLED_APPS
+    app_config["INSTALLED_APPS"] = list(set(app_config["INSTALLED_APPS"]))
+
     app_config.update(
         config or {},
         **{
@@ -196,6 +207,21 @@ def setup_config(config):
     return {key: deepcopy(val) for key, val in app_config.items()}
 
 
+def update_config_from_step(context, config):
+    context.app.config.update(config)
+
+    if "MEDIA_STORAGE_PROVIDER" in config or "AMAZON_CONTAINER_NAME" in config:
+        context.app.media = get_media_storage_class(context.app.config)(context.app)
+
+    if "AMAZON_CONTAINER_NAME" in config:
+        if isinstance(context.app.media, AmazonMediaStorage):
+            m = patch.object(context.app.media, "client")
+            m.start()
+        elif isinstance(context.app.media, ProxyMediaStorage):
+            m = patch.object(context.app.media.storage(), "client")
+            m.start()
+
+
 def clean_dbs(app, force=False):
     _clean_es(app)
     drop_mongo(app)
@@ -424,10 +450,8 @@ def setup_ad_user(context, user):
         "sign_off": ad_user.get("sign_off", "abc"),
         "preferences": {
             "email:notification": {
-                "label": "Send notifications via email",
                 "type": "bool",
                 "default": True,
-                "category": "notifications",
                 "enabled": True,
             }
         },
