@@ -11,11 +11,12 @@
 
 import logging
 import json
+from typing import List, Union, Any, Dict
 
 from flask import request, current_app as app
 from eve.utils import config
 from eve.methods.common import serialize_value
-from flask_babel import _
+from flask_babel import _, lazy_gettext
 
 from superdesk import privilege, get_resource_service
 from superdesk.notification import push_notification
@@ -32,7 +33,11 @@ logger = logging.getLogger(__name__)
 KEYWORDS_CV = "keywords"
 
 
-privilege(name="vocabularies", label="Vocabularies Management", description="User can manage vocabularies' contents.")
+privilege(
+    name="vocabularies",
+    label=lazy_gettext("Vocabularies Management"),
+    description=lazy_gettext("User can manage vocabularies' contents."),
+)
 
 
 # TODO(petr): add api to specify vocabulary schema
@@ -444,6 +449,72 @@ class VocabulariesService(BaseService):
         article_item.update({"scheme": scheme})
         return article_item
 
+    def get_items(
+        self, _id: str, qcode: str = None, is_active: bool = True, name: str = None, lang: str = None
+    ) -> List:
+        """
+        Return `items` with specified filters from the CV with specified `_id`.
+        If `lang` is provided then `name` is looked in `items.translations.name.{lang}`,
+        otherwise `name` is looked in `items.name`.
+
+        :param _id: custom vocabulary _id
+        :param qcode: items.qcode filter
+        :param is_active: items.is_active filter
+        :param name: items.name filter
+        :param lang: items.lang filter
+        :return: items list
+        """
+
+        projection: Dict[str, Any] = {}
+        lookup = {"_id": _id}
+
+        if qcode:
+            elem_match = projection.setdefault("items", {}).setdefault("$elemMatch", {})
+            elem_match["qcode"] = qcode
+
+        # if `lang` is provided `name` is looked in `translations.name.{lang}`
+        if name and lang:
+            elem_match = projection.setdefault("items", {}).setdefault("$elemMatch", {})
+            elem_match[f"translations.name.{lang}"] = {
+                "$regex": r"^{}$".format(name),
+                # case-insensitive
+                "$options": "i",
+            }
+        elif name:
+            elem_match = projection.setdefault("items", {}).setdefault("$elemMatch", {})
+            elem_match["name"] = {
+                "$regex": r"^{}$".format(name),
+                # case-insensitive
+                "$options": "i",
+            }
+
+        cursor = self.get_from_mongo(req=None, lookup=lookup, projection=projection)
+
+        try:
+            items = cursor.next()["items"]
+        except (StopIteration, KeyError):
+            return []
+
+        # $elemMatch projection contains only the first element matching the condition,
+        # that"s why `is_active` filter is filtered via python
+        if is_active is not None:
+            items = [i for i in items if i.get("is_active", True) == is_active]
+
+        def format_item(item):
+            try:
+                del item["is_active"]
+            except KeyError:
+                pass
+            item["scheme"] = _id
+            return item
+
+        items = list(map(format_item, items))
+
+        return items
+
+    def get_languages(self):
+        return self.get_items(_id="languages")
+
 
 def is_related_content(item_name, related_content=None):
     if related_content is None:
