@@ -9,20 +9,20 @@ from superdesk.errors import SuperdeskIngestError
 
 
 class TestFeedingService(FeedingService):
-    Name = 'test_feeding'
+    Name = "test_feeding"
 
     def _update(self, provider, update):
         pass
 
 
 class FeedingServiceParserTestCase(TestCase):
-
     def test_restricted_parser(self):
         feeding_service = TestFeedingService()
-        with patch.dict('superdesk.io.feeding_services.restricted_feeding_service_parsers',
-                        {'test_feeding': {'ninjs': True}}):
+        with patch.dict(
+            "superdesk.io.feeding_services.restricted_feeding_service_parsers", {"test_feeding": {"ninjs": True}}
+        ):
             with self.assertRaises(SuperdeskIngestError):
-                feeding_service.config_test({'feed_parser': 'foo', 'feeding_service': 'test_feeding'})
+                feeding_service.config_test({"feed_parser": "foo", "feeding_service": "test_feeding"})
 
     def test_add_timestamps_warning(self):
         item = {}
@@ -34,8 +34,8 @@ class FeedingServiceParserTestCase(TestCase):
         assert issubclass(w[0].category, DeprecationWarning)
 
     def test_localize_timestamps(self):
-        item = {'firstcreated': datetime(2019, 10, 15, 10, 59, 0)}
-        self.assertIsNone(item['firstcreated'].tzinfo)
+        item = {"firstcreated": datetime(2019, 10, 15, 10, 59, 0)}
+        self.assertIsNone(item["firstcreated"].tzinfo)
         feeding_service = TestFeedingService()
         feeding_service.localize_timestamps(item)
-        self.assertEqual(pytz.utc, item['firstcreated'].tzinfo)
+        self.assertEqual(pytz.utc, item["firstcreated"].tzinfo)
