@@ -1,4 +1,3 @@
-
 import unittest
 
 from superdesk.io.feeding_services.http_base_service import HTTPFeedingServiceBase
@@ -6,17 +5,16 @@ from superdesk.io.feeding_services.http_base_service import HTTPFeedingServiceBa
 
 class FeedingServiceWithUrl(HTTPFeedingServiceBase):
 
-    URL = 'http://example.com'
+    URL = "http://example.com"
 
     fields = []
 
-    def _update():
+    def _update(self, provider, update):
         pass
 
 
 class TestFeedingService(unittest.TestCase):
-
     def test_validate_config_url_null(self):
         service = FeedingServiceWithUrl()
-        service.provider = {'config': {'url': None}}
+        service.provider = {"config": {"url": None}}
         service.validate_config()
