@@ -15,24 +15,17 @@ from superdesk.macros.validate_for_publish import validate_for_publish, Validati
 
 
 class ValidateForPublishTests(TestCase):
-    validator = {'_id': 'publish_text',
-                 'act': 'publish',
-                 'type': 'text',
-                 'schema': {
-                     'headline': {
-                         'required': True,
-                         'maxlength': 5,
-                         'empty': False,
-                         'nullable': False,
-                         'type': "string"
-                     }
-                 }
-                 }
+    validator = {
+        "_id": "publish_text",
+        "act": "publish",
+        "type": "text",
+        "schema": {"headline": {"required": True, "maxlength": 5, "empty": False, "nullable": False, "type": "string"}},
+    }
 
     def test_validator(self):
-        self.app.data.insert('archive', [{'_id': 1, 'type': 'text', 'headline': '123456'}])
-        self.app.data.insert('validators', [self.validator])
+        self.app.data.insert("archive", [{"_id": 1, "type": "text", "headline": "123456"}])
+        self.app.data.insert("validators", [self.validator])
         with self.app.app_context():
             with assert_raises(ValidationError):
-                item = {'_id': 1}
+                item = {"_id": 1}
                 validate_for_publish(item)
