@@ -5,14 +5,13 @@ from apps.rules.routing_rules import Weekdays
 
 
 class WeekdaysTestCase(unittest.TestCase):
-
     def test_is_valid_schedule(self):
-        self.assertTrue(Weekdays.is_valid_schedule(['MON', 'TUE']))
-        self.assertFalse(Weekdays.is_valid_schedule(['MON', 'SRC']))
+        self.assertTrue(Weekdays.is_valid_schedule(["MON", "TUE"]))
+        self.assertFalse(Weekdays.is_valid_schedule(["MON", "SRC"]))
 
     def test_is_scheduled(self):
         now = datetime.now()
-        day = now.strftime('%A')[:3]
+        day = now.strftime("%A")[:3]
 
         self.assertFalse(Weekdays.is_scheduled_day(now, []))
         self.assertTrue(Weekdays.is_scheduled_day(now, [day]))
@@ -20,5 +19,5 @@ class WeekdaysTestCase(unittest.TestCase):
 
     def test_weekday_dayname(self):
         now = datetime.now()
-        day = now.strftime('%A')[:3].upper()
+        day = now.strftime("%A")[:3].upper()
         self.assertEqual(day, Weekdays.dayname(now))
